package com.zhilian.online.config;

import lombok.extern.slf4j.Slf4j;
import org.eclipse.paho.client.mqttv3.*;
import org.eclipse.paho.client.mqttv3.persist.MemoryPersistence;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;

/**
 * @BelongsProject: smart-cloud-server
 * @BelongsPackage: com.zhilian.online.config
 * @Author: LiYuan
 * @CreateTime: 2024-03-31  09:45
 * @Description: TODO
 * @Version: 1.0
 */
@Component
@Slf4j
public class MqttxConfig {

    /**
     * 路径
     */
    @Value("${mqtt.server.broker}")
    private String broker;

    /**
     * 主题
     */
    @Value("${mqtt.server.topic}")
    private String topic;

    /**
     * 客户端ID
     */
    @Value("${mqtt.server.clientId}")
    private String clientId;

    /**
     * 用户名
     */
    @Value("${mqtt.server.username}")
    private String username;

    /**
     * 密码
     */
    @Value("${mqtt.server.password}")
    private String password;

    /**
     * qos
     */
    @Value("${mqtt.server.qos}")
    private Integer qos;


    @PostConstruct
    public void initMqtt() {
        log.info("mqttx连接中......");

        try {
            MqttClient mqttClient = new MqttClient(broker, clientId, new MemoryPersistence());

            MqttConnectOptions mqttConnectOptions = new MqttConnectOptions();

            mqttConnectOptions.setUserName(username);
            mqttConnectOptions.setPassword(password.toCharArray());

            //链接超时
            mqttConnectOptions.setConnectionTimeout(60);
            //心跳检测
            mqttConnectOptions.setKeepAliveInterval(60);
            mqttClient.connect(mqttConnectOptions);
            log.info("mqtt{}服务连接成功", broker);

            //回调
            mqttClient.setCallback(new MqttCallback() {
                @Override
                public void connectionLost(Throwable throwable) {
                    log.error("连接断开{}", throwable.getMessage());
                }

                @Override
                public void messageArrived(String s, MqttMessage mqttMessage) throws Exception {
                    log.info("消息到达,接受消息主题{},接受消息Qos{},接受消息内容{}", topic, mqttMessage.getQos(), new String(mqttMessage.getPayload()));
                }

                @Override
                public void deliveryComplete(IMqttDeliveryToken iMqttDeliveryToken) {
                    log.info("消息{}发送成功" + iMqttDeliveryToken.isComplete());
                }
            });

            mqttClient.subscribe(topic,qos);

        } catch (MqttException e) {
            throw new RuntimeException(e);
        }


    }


}
