package com.zhilian.online.controller;

import com.alibaba.fastjson2.JSON;
import com.zhilian.common.core.domain.Result;
import com.zhilian.common.core.utils.ip.IpUtils;
import com.zhilian.common.core.web.controller.BaseController;

import com.zhilian.online.domain.Gather;
import com.zhilian.online.domain.req.GatherRegReq;
import com.zhilian.online.service.OnlineLoadCenterService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * @version:
 * @Author: LiYuan
 * @description: 负载中心Controller
 * @date: 2024/3/29  20:40
 */
@RestController
@RequestMapping("/load/center")
@Slf4j
public class OnlineLoadCenterController extends BaseController {

    /**
     * 请求对象
     */
    @Autowired
    private HttpServletRequest request;

    /**
     * 车辆收集节点服务层
     */
    @Autowired
    private OnlineLoadCenterService onlineLoadCenterService;


    /**
     * @description: 节点申请注解令牌接口,仅限内网访问
     * @author: LiYuan
     * @param: vehicle
     * @return: Result<OnlineAccount>
     **/
    @GetMapping("/applyForReg")
    public Result<String> applyForReg(){
        log.info("申请注册令牌");
        return onlineLoadCenterService.applyForReg();
    }


    /**
     * @description: 收集节点注册
     * @author: LiYuan
     * @param: Gather
     * @return: Result
     **/
    @PostMapping("/regGather")
    public Result regGather(@Validated Gather gather){
        String ipAddr = IpUtils.getIpAddr(request);
        gather.setIpAddress(ipAddr);
        log.info("节点{}正在上线",gather);
        return onlineLoadCenterService.regGather(gather);
    }


    /**
     * 车辆上线至收集节点
     * @return null
     */
    public Result getConnectionOption(){

        return null;
    }


}
